"""
Search an object for a given search term.
:param obj: The object to search in.
:param query: What to search for.
:param max_depth: The maximum depth of the recursive search.
:param top_k_results: The maximum number of results to return.
:param max_iterable_length: The maximum length of an iterable to search in.
:param get_raw_result: If True, return the raw results (of type SearchResult), else just print them.
:return: A list of search results.
"""
from sys import modules
from types import ModuleType
from .search_object import searchin
__all__ = ['searchin']


class CallableModule(ModuleType):
    """Inspired from https://stackoverflow.com/a/74604283"""
    def __init__(self):
        ModuleType.__init__(self, __name__)
        self.__dict__.update(modules[__name__].__dict__)
            
    def __call__(self, *args, **kwargs):
        searchin(*args, **kwargs)
            
    mod_call= __call__
    __all__= list(set(vars().keys()) - {'__qualname__'})

modules[__name__]= CallableModule()



"""Setup.py for Pypi.org"""
from distutils.core import setup

setup(
    name='searchin',
    packages=['searchin'],
    version='0.2.3',
    description='Search anything in a live python object, method or variable',
    author='Nicolas Micaux',

    url='https://github.com/NicolasMICAUX/searchin',
    # download_url='https://github.com/NicolasMICAUX/searchin/archive/refs/tags/v0.1.5.tar.gz',

    install_requires=[],  # None

    keywords=['search', 'debug', 'inspect'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Topic :: Software Development',
        'Topic :: Software Development :: Debuggers',
        'Topic :: Utilities',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
    ],
    python_requires='>=2.7',

    # Set README.md as description
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
)



from unittest import TestCase
from searchin import searchin


class MyClass:
    def __init__(self):
        self.a = 1
        self.b = 2
        self.c = 3

    def my_method(self):
        gamma = 1

    def my_other_method(self):
        pass


class Test(TestCase):
    def test_search_object(self):
        for result in searchin(MyClass(), 'gamma'):
            print(result)
            self.assertEqual(result.query, 'gamma')
